==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_village_around.lua <==
function E0090()
    InitRoom()FAI(0)
end
function E0091()
    InitRoom()FAI(1)
end
function E0092()
    InitRoom()FAI(2)
end
function E0093()
    InitRoom()FAI(3)
end
function E0094()
    InitRoom()FAI(4)
end

function InitRoom()
    MNA()
    if(FLJ("KingBack")) then
        CMU("CS_Quiet")
    else
        CMU("CS_Mura")
    end
end

function GoVillage()
    PRI()FAO(3)TRA("CS_village","E0091",58,12,1,12)
end

function GoCrossRoads()
    if(FLJ("KingBack")) then
        PRI()FAO(1)TRA("CS_crossroads2","E0093",1,14,1,9)
    else
        PRI()FAO(1)TRA("CS_crossroads","E0093",1,14,1,9)
    end
end

--游戏起始事件
function GameStart()
    KEY()
    --创建实体
    SNP("null",51,12,0,"mainLayer","Camera1")
    SNP("CS_mychar_kanpa_animate",47,13,0,"mainLayer","Kanpa1")
    SNP("CS_bucket",48,13,0,"mainLayer","Bucket1")
    SNP("CS_enemy_chinfish",42,17,1,"mainLayer","")
    DNP("SavePoint")
    FON("Camera1",0)
    MOV(47,13)
    --间八钓鱼
    ANP("Kanpa1",200,0)--显示鱼竿
    ANP("Kanpa1",3,0)--坐着
    ANP("Kanpa1",203,0)--闭上眼
    CMU("CS_Mura")
    FAI(4)
    WAI(64)
    ANP("Kanpa1",202,0)--睁开眼
    WAI(32)
    MS3("今天钓的鱼也足够了,")NOD()
    CAT("\n那么回去吧~")NOD()CLO()
    ITP("Chinfish")
    MSA("AskEveryoneAboutMahin")
    WAI(16)
    ANP("Kanpa1",0,0)--站起
    WAI(32)
    FAO(0)
    --切换房间
    TRA("CS_kanpa_house","KanpaBackHome",14,14)
end

--钓鱼
function Fishing1()
    PRI()
    if(WET()) then
        MS4("鱼还在水中活蹦乱跳的，")NOD()
        CAT("没法捕获。")NOD()
    else
        MS4("\n这是村里鱼塘常见的珍鱼...")NOD()CLR()
        ITP("Chinfish")
        GIT("Chinfish")
        SOU("CS_038_get_item")
        DNP("Fishing1")
        FLP("Fishing1")
        CMU("CS_Fanfale1")
        CAT("\n获得了 =珍鱼= 。")WAI(160)NOD()
        RMU()
    end
end

function SueAndTorokoLookForCat()
    KEY()
    CMU("CS_Mura")
    SNP("CS_sue_animate",64,9,0,"mainLayer","Sue1")--数
    ANP("Sue1","back",0)
    SNP("CS_toroko_animate",49,13,1,"mainLayer","Toroko1")--多隆子
    ANP("Toroko1","normal",1)
    FAI(2)
    WAI(32)
    FAC("sue_normal")MS3("这里就是当时我看到大猫的地方了，")NOD()
    ANP("Sue1","normal",0)
    FAC("sue_sad")CAT("\n不过它现在没有出现呢...")NOD()CLR()
    FAC("toroko_normal")CAT("\n可能猫先生这个时候还没醒来吧...")NOD()CLO()
    CMU("XXXX")
    QUA(30)
    MS3("？")NOD()CLO()
    SNP("CS_puu_animate",66,-2,0,"mainLayer","Puu1")--Puu
    ANP("Puu1","dark")
    ANP("Puu1",1060,0)
    WAI(64)
    ANP("Sue1","normal",1)
    WAI(32)
    ANP("Sue1","hurt_down",1)
    WAI(32)
    FAC("toroko_><")MS3("\n数姐姐！！")NOD()CLR()
    FAC("sue_hurt")CAT("有怪物！！")NOD()
    CAT("\n多隆子快跑！！")NOD()CLO()
    CMU("CS_Escape")
    ANP("Puu1","open_mouth")
    WAI(16)
    SNP("CS_bubble_catcher",66,9,0,"mainLayer","Bubble1")
    SOU("CS_021_bubble")
    ANP("Bubble1","set_target")
    ANP("Bubble1","Toroko1")
    --多隆子逃跑
    FON("Toroko1")
    ANP("Toroko1","run",0)
    ANP("Toroko1","jump",0)
    WAI(16)
    ANP("Puu1","normal")
    WAI(24)
    ANP("Toroko1","big_jump",0)
    WAI(52)
    ANP("Toroko1","big_jump",0)
    WAI(40)
    ANP("Toroko1","big_jump",0)
    WAI(300)
    ANP("Bubble1","top_draw_false")
    FAO(3)
    TRA("CS_village","TorokoHasBeenCaptured",46,11)
end

==> ocstore25_6_20.zip: OcStore/Prgm/data/map/CS_village_around.lua <==
function E0090()
    InitRoom()FAI(0)
end
function E0091()
    InitRoom()FAI(1)
end
function E0092()
    InitRoom()FAI(2)
end
function E0093()
    InitRoom()FAI(3)
end
function E0094()
    InitRoom()FAI(4)
end

function InitRoom()
    MNA()
    if(FLJ("KingBack")) then
        CMU("CS_Quiet")
    else
        CMU("CS_Mura")
    end
end

function GoVillage()
    PRI()FAO(3)TRA("CS_village","E0091",58,12,1,12)
end

function GoCrossRoads()
    if(FLJ("KingBack")) then
        PRI()FAO(1)TRA("CS_crossroads2","E0093",1,14,1,9)
    else
        PRI()FAO(1)TRA("CS_crossroads","E0093",1,14,1,9)
    end
end

--游戏起始事件
function GameStart()
    KEY()
    --创建实体
    SNP("null",51,12,0,"mainLayer","Camera1")
    SNP("CS_mychar_kanpa_animate",47,13,0,"mainLayer","Kanpa1")
    SNP("CS_bucket",48,13,0,"mainLayer","Bucket1")
    SNP("CS_enemy_chinfish",42,17,1,"mainLayer","")
    DNP("SavePoint")
    FON("Camera1",0)
    MOV(47,13)
    --间八钓鱼
    ANP("Kanpa1",200,0)--显示鱼竿
    ANP("Kanpa1",3,0)--坐着
    ANP("Kanpa1",203,0)--闭上眼
    CMU("CS_Mura")
    FAI(4)
    WAI(64)
    ANP("Kanpa1",202,0)--睁开眼
    WAI(32)
    MS3("今天钓的鱼也足够了,")NOD()
    CAT("\n那么回去吧~")NOD()CLO()
    ITP("Chinfish")
    MSA("AskEveryoneAboutMahin")
    WAI(16)
    ANP("Kanpa1",0,0)--站起
    WAI(32)
    FAO(0)
    --切换房间
    TRA("CS_kanpa_house","KanpaBackHome",14,14)
end

--钓鱼
function Fishing1()
    PRI()
    if(WET()) then
        MS4("鱼还在水中活蹦乱跳的，")NOD()
        CAT("没法捕获。")NOD()
    else
        MS4("\n这是村里鱼塘常见的珍鱼...")NOD()CLR()
        ITP("Chinfish")
        GIT("Chinfish")
        SOU("CS_038_get_item")
        DNP("Fishing1")
        FLP("Fishing1")
        CMU("CS_Fanfale1")
        CAT("\n获得了 =珍鱼= 。")WAI(160)NOD()
        RMU()
    end
end

function SueAndTorokoLookForCat()
    KEY()
    CMU("CS_Mura")
    SNP("CS_sue_animate",64,9,0,"mainLayer","Sue1")--数
    ANP("Sue1","back",0)
    SNP("CS_toroko_animate",49,13,1,"mainLayer","Toroko1")--多隆子
    ANP("Toroko1","normal",1)
    FAI(2)
    WAI(32)
    FAC("sue_normal")MS3("这里就是当时我看到大猫的地方了，")NOD()
    ANP("Sue1","normal",0)
    FAC("sue_sad")CAT("\n不过它现在没有出现呢...")NOD()CLR()
    FAC("toroko_normal")CAT("\n可能猫先生这个时候还没醒来吧...")NOD()CLO()
    CMU("XXXX")
    QUA(30)
    MS3("？")NOD()CLO()
    SNP("CS_puu_animate",66,-2,0,"mainLayer","Puu1")--Puu
    ANP("Puu1","dark")
    ANP("Puu1",1060,0)
    WAI(64)
    ANP("Sue1","normal",1)
    WAI(32)
    ANP("Sue1","hurt_down",1)
    WAI(32)
    FAC("toroko_><")MS3("\n数姐姐！！")NOD()CLR()
    FAC("sue_hurt")CAT("有怪物！！")NOD()
    CAT("\n多隆子快跑！！")NOD()CLO()
    CMU("CS_Escape")
    ANP("Puu1","open_mouth")
    WAI(16)
    SNP("CS_bubble_catcher",66,9,0,"mainLayer","Bubble1")
    SOU("CS_021_bubble")
    ANP("Bubble1","set_target")
    ANP("Bubble1","Toroko1")
    --多隆子逃跑
    FON("Toroko1")
    ANP("Toroko1","run",0)
    ANP("Toroko1","jump",0)
    WAI(16)
    ANP("Puu1","normal")
    WAI(24)
    ANP("Toroko1","big_jump",0)
    WAI(52)
    ANP("Toroko1","big_jump",0)
    WAI(40)
    ANP("Toroko1","big_jump",0)
    WAI(300)
    ANP("Bubble1","top_draw_false")
    FAO(3)
    TRA("CS_village","TorokoHasBeenCaptured",46,11)
end

function Credit_Cut()
    KEY()
    local helicopter_x =25;
    local helicopter_y =12;
    SNP("CS_helicopter",helicopter_x,helicopter_y,0,"mainLayer","Helicopter1")
    ANP("Helicopter1","mute")
    ANP("Helicopter1","fly")
    ANP("Helicopter1","set_manned")
    ANP("Helicopter1","leave")
    SNP("CS_quote_animate",helicopter_x+1,helicopter_y-1,0,"mainLayer","Quote1")
    SNP("CS_curly_animate",helicopter_x,helicopter_y-1,0,"mainLayer","Curly1")

   
    SNP("CS_jack_animate",helicopter_x-16,12,1,"mainLayer","Jack1")
    SNP("CS_santa_animate",helicopter_x-15,12,1,"mainLayer","Santa1")
    SNP("CS_mahin_animate",helicopter_x-14,12,1,"mainLayer","Mahin1")
    SNP("CS_mychar_kanpa_animate",helicopter_x-13,12,1,"mainLayer","Kanpa1")
    SNP("CS_chako_animate",helicopter_x-12,12,1,"mainLayer","Chako1")
    SNP("CS_sue_animate",helicopter_x-11,12,1,"mainLayer","Sue1")
    SNP("CS_toroko_animate",helicopter_x-10,12,1,"mainLayer","Toroko1")
    SNP("CS_colon_animate",helicopter_x-9,12,1,"mainLayer","Colon1")
    SNP("CS_colon_animate",helicopter_x-8,12,1,"mainLayer","Colon2")
    SNP("CS_colon_animate",helicopter_x-7,12,1,"mainLayer","Colon3")
    SNP("CS_colon_animate",helicopter_x-6,12,1,"mainLayer","Colon4")

    SNP("CS_king_animate",helicopter_x-4,12,1,"mainLayer","King1")
    FAI(2)
    WAI(700)
    FAO(2)
    TRA("CS_credit","Credit_Cut8",0,0)
end
